@@ -10,7 +10,7 @@ import pygame
 # do these things yourself.  (Check the source, it's not hard.)
 rabbyt.init_display((640, 480))
 
-while True:
+while not pygame.event.peek(pygame.QUIT):
     # Clear the screen to white.  (Colors in rabbyt are the same as in OpenGL,
     # from 0.0 to 1.0.)
     rabbyt.clear((1.0,1.0,1.0))
